@@ -17,17 +17,13 @@ C1 <- expmCond(M, "exact")
 (C3.  <- expmCond(M, "F.est", abstol = 0.1)[[1]])
 (C3.1 <- expmCond(M, "F.est", abstol = 0.01, reltol = 1e-12)[[1]])
 
-stopifnot(all.equal(C1[1:2], eC, tol = 1e-14),
-          all.equal(C2  , eC$expmCond1, tol = 1e-14),
-          all.equal(C3. , eC$expmCondF, tol = 1e-14, check.attributes = FALSE),
-          all.equal(C3.1, eC$expmCondF, tol = 1e-14, check.attributes = FALSE))
+stopifnot(all.equal(C1[1:2], eC, tolerance = 1e-14),
+	  all.equal(C2	, eC$expmCond1, tolerance = 1e-14),
+	  all.equal(C3. , eC$expmCondF, tolerance = 1e-14, check.attributes = FALSE),
+	  all.equal(C3.1, eC$expmCondF, tolerance = 1e-14, check.attributes = FALSE))
 
 cat('Time elapsed: ', (p1 <- proc.time()),'\n') # for ``statistical reasons''
 
+## cat('Time elapsed: ',(p2 <- proc.time())-p1,'\n') # for ``statistical reasons''
 
-
-cat('Time elapsed: ',(p2 <- proc.time())-p1,'\n') # for ``statistical reasons''
-
-
-
-cat('Time elapsed: ',(p3 <- proc.time())-p2,'\n') # for ``statistical reasons''
+## cat('Time elapsed: ',(p3 <- proc.time())-p2,'\n') # for ``statistical reasons''
